# MockSZ
[![DOI](https://zenodo.org/badge/662176943.svg)](https://zenodo.org/badge/latestdoi/662176943)

A Python package to create mock Sunyaev-Zel'dovich maps. 
For installation instructions, tutorials, etc., please see the [documentation pages](https://arend95.github.io/MockSZ/).
